@@ -143,6 +143,7 @@ write_secret_file (const char *path,
 	success = TRUE;
 
 out:
+	g_free (tmppath);
 	return success;
 }
 
@@ -937,20 +938,11 @@ write_wired_setting (NMConnection *connection, shvarFile *ifcfg, GError **error)
 static void
 write_connection_setting (NMSettingConnection *s_con, shvarFile *ifcfg)
 {
-	char *tmp;
-
 	svSetValue (ifcfg, "NAME", nm_setting_connection_get_id (s_con), FALSE);
 	svSetValue (ifcfg, "UUID", nm_setting_connection_get_uuid (s_con), FALSE);
 	svSetValue (ifcfg, "ONBOOT",
 	            nm_setting_connection_get_autoconnect (s_con) ? "yes" : "no",
 	            FALSE);
-
-	svSetValue (ifcfg, "LAST_CONNECT", NULL, FALSE);
-	if (nm_setting_connection_get_timestamp (s_con)) {
-		tmp = g_strdup_printf ("%" G_GUINT64_FORMAT, nm_setting_connection_get_timestamp (s_con));
-		svSetValue (ifcfg, "LAST_CONNECT", tmp, FALSE);
-		g_free (tmp);
-	}
 }
 
 static gboolean
